DukeUltrasound is an ultrasound dataset collected at Duke University with a
Verasonics c52v probe. It contains delay-and-sum (DAS) beamformed data as well
as data post-processed with Siemens Dynamic TCE for speckle reduction, contrast
enhancement and improvement in conspicuity of anatomical structures. These data
were collected with support from the National Institute of Biomedical Imaging
and Bioengineering under Grant R01-EB026574 and National Institutes of Health
under Grant 5T32GM007171-44. A usage example is available
[here](https://colab.research.google.com/drive/1R_ARqpWoiHcUQWg1Fxwyx-ZkLi0IZ5qs).
